@@ -1,6 +1,7 @@
 import argparse
 import importlib
 import os
+import sys
 
 from .config import Config
 from .generator import generate_ini, generate_json, generate_toml
@@ -12,8 +13,6 @@ group.add_argument('name', type=str, )
 group.add_argument('path', type=str)
 group.add_argument('--rewrite', action='store_true')
 
-args = args_parser.parse_args()
-
 
 def find_by_name(name: str):
     for c in Config.find_all_subclasses():
@@ -21,7 +20,9 @@ def find_by_name(name: str):
             return c
 
 
-def main(args):
+def main():
+    args = args_parser.parse_args()
+    sys.path.extend([os.getcwd()])
     try:
         importlib.import_module(args.package)
     except Exception as e:
@@ -52,4 +53,4 @@ def main(args):
 
 
 if __name__ == "__main__":
-    main(args)
+    main()
